summaryrefslogtreecommitdiffstats
path: root/kdessh/sshdlg.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:32:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-06 02:32:00 -0600
commit27f2cfdc57b75ea3994e31ad436464353d966cdd (patch)
tree0aab4fe14ca3ea9071b7a0d97529996e5bb35440 /kdessh/sshdlg.cpp
parent73dc36225d414b2108708fac11960774f74a3a8a (diff)
downloadtdeutils-27f2cfdc57b75ea3994e31ad436464353d966cdd.tar.gz
tdeutils-27f2cfdc57b75ea3994e31ad436464353d966cdd.zip
Additional kde to tde renaming
Diffstat (limited to 'kdessh/sshdlg.cpp')
-rw-r--r--kdessh/sshdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdessh/sshdlg.cpp b/kdessh/sshdlg.cpp
index 49f4e52..62dcd24 100644
--- a/kdessh/sshdlg.cpp
+++ b/kdessh/sshdlg.cpp
@@ -2,14 +2,14 @@
*
* $Id$
*
* This file is part of the KDE project, module kdesu.
* Copyright (C) 2000 Geert Jansen <jansen@kde.org>
*/
#include <klocale.h>
#include <kmessagebox.h>
-#include <kdesu/ssh.h>
+#include <tdesu/ssh.h>
#include "sshdlg.h"
@@ -59,7 +59,7 @@ bool KDEsshDialog::checkPassword(const char *password)
case SshProcess::SshNotFound:
KMessageBox::sorry(this,
- i18n("The programs 'ssh' or 'kdesu_stub' cannot be found.\n"
+ i18n("The programs 'ssh' or 'tdesu_stub' cannot be found.\n"
"Make sure your PATH is set correctly."));
done(Rejected);
return false;
@@ -2,14 +2,14 @@
* $Id$
*
- * This file is part of the KDE project, module kdesu.
+ * This file is part of the KDE project, module tdesu.
* Copyright (C) 2000 Geert Jansen <jansen@kde.org>
*/